pub struct BatchAdapter { /* private fields */ }Expand description
Adapter for transforming record batches to match a target schema.
Create instances via BatchAdapterFactory.
Performance
The adapter pre-computes the projection expressions during creation,
so the adapt_batch call is efficient and suitable
for use in hot paths like streaming file scans.
Implementations
Sourceimpl BatchAdapter
impl BatchAdapter
Sourcepub fn adapt_batch(&self, batch: &RecordBatch) -> Result<RecordBatch>
pub fn adapt_batch(&self, batch: &RecordBatch) -> Result<RecordBatch>
Adapt the given record batch to match the target schema.
The input batch must conform to the source schema used when creating this adapter.